import {
  select,
  csv,
  scaleLinear,
  extent,
  max,
  axisLeft,
  axisBottom,
  format
} from 'd3';
import { dropdownmenu } from './dropdownmenu';
import {scatterplot} from './scatterPlot.js';



const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

let data;
let yColumn;

const onYColumnClicked = column => {
  yColumn = column;
  render();
};

const render = () => {
  
  console.log(data.columns);
  
  select('#menus')
		.call(dropdownmenu, {
  		options: data.columns,
    	onOptionClicked: onYColumnClicked
		});
  
  svg.call(scatterPlot, {
    title: 'Pollution and Income',
		xValue: d => d.ds_pm_pred,
		xAxisLabel: 'Air Pollution',
		yValue: d => d[yColumn],
		circleRadius: 2,
		yAxisLabel: 'Median Household Income',
		margin: { top: 100, right: 120, bottom: 100, left: 120 },
    width,
    height,
    data
  });
};

csv('data.csv')
  .then(loadedData => {
  data = loadedData;
  data.forEach(d => {
    d.ds_pm_pred = +d.ds_pm_pred;
    d.MdnHHIncome = +d.MdnHHIncome;
    d.PercBlwPvrty = +d.PercBlwPvrty;
  });
  render();
});