import {
  select,
  csv,
  scaleLinear,
  extent,
  max,
  axisLeft,
  axisBottom,
  format
} from 'd3';

export const scatterPlot = (selection, props) => {
  const {
    title,
    xValue,
    xAxisLabel,
		yValue,
    circleRadius,
    yAxisLabel,
  	margin,
    width,
    height,
    data 
  } = props;
  

  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  const g = selection.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxisTickFormat = number =>
    format('.3s')(number);
  
  const xAxis = axisBottom(xScale)
    .tickFormat(xAxisTickFormat)
    .tickSize(-innerHeight)
  	.tickPadding(20);
  
	const yAxisTickFormat = number =>
    format('.2s')(number);
  
  const yAxis = axisLeft(yScale)
  	.tickFormat(yAxisTickFormat)
  	.tickSize(-innerWidth)
  	.tickPadding(20);

  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'yAxis-label')
      .attr('y', -95)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
  		.attr('text-anchor', 'middle')
    	.text(yAxisLabel);
  
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'xAxis-label')
      .attr('y', 90)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  g.selectAll('circl').data(data)
    .enter().append('circle')
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius);
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -40)
  		.attr('x', -105)
      .text('Air Pollution and Median Income');
}